@@ -7,6 +7,8 @@ from .commands.login import handle as handleLogin
 from .commands.me import handle as handleMe
 from .commands.watchpage import handle as handleWatchPage
 from .commands.watchresult import handle as handleWatchResult
+from .commands.addproblem import handle as handleAddProblem
+from .commands.initproblem import handle as handleInitProblem
 
 def dispatch_args():
     """
@@ -25,7 +27,7 @@ def dispatch_args():
             ''',
         )
 
-        subparsers = parser.add_subparsers(dest="command", help="sub command", required=True)
+        subparsers = parser.add_subparsers(dest="command", required=True)
         login_parser = subparsers.add_parser(
             "login",
             help = "login with your username and password,"
@@ -42,7 +44,6 @@ def dispatch_args():
         )
         result_subparsers = result_parser.add_subparsers(
             dest="result_subcommand",
-            help = "result's subcommand",
             required=True
         )
         result_watch_parser = result_subparsers.add_parser(
@@ -67,6 +68,35 @@ def dispatch_args():
             help="The id of the contest, like 'abc123'"
         )
 
+        problem_parser = subparsers.add_parser(
+            "problem",
+            help="operate with problems(like submit, add)"
+        )
+        problem_subparsers = problem_parser.add_subparsers(
+            dest = "problem_subcommand",
+            required = True
+        )
+        problem_add_parser = problem_subparsers.add_parser(
+            "add",
+            help = "add a problem to solve"
+        )
+        problem_add_parser.add_argument(
+            "contest_id",
+            help = "The id of the contest, like 'abc123'"
+        )
+        problem_add_parser.add_argument(
+            "problem_id",
+            help = "The id of the problem, like 'a' or 'g'"
+        )
+        problem_init_parser = problem_subparsers.add_parser(
+            "init",
+            help = "init problem.yaml in current dir"
+        )
+        problem_init_parser.add_argument(
+            "--force",
+            action = "store_true"
+        )
+
         arg = parser.parse_args()
         if arg.command == 'login':
             handleLogin(console, arg)
@@ -77,6 +107,11 @@ def dispatch_args():
                 handleWatchResult(console, arg)
             if arg.result_subcommand == 'page':
                 handleWatchPage(console, arg)
+        if arg.command == 'problem':
+            if arg.problem_subcommand == 'add':
+                handleAddProblem(console, arg)
+            if arg.problem_subcommand == 'init':
+                handleInitProblem(console, arg)
 
     except KeyboardInterrupt:
         console.log("[red]FATAL:Interrupted.[/red]")
